pub struct LicenseCheckedGuard<G: Guard> { /* private fields */ }Expand description
Wrapper for a guard that performs license checks.
This wrapper validates the license before each guard check, returning an error if the required feature is not licensed.
Implementations
Sourceimpl<G: Guard> LicenseCheckedGuard<G>
impl<G: Guard> LicenseCheckedGuard<G>
Sourcepub fn new(
inner: G,
feature_name: impl Into<String>,
tier_name: impl Into<String>,
validator: Arc<LicenseValidator>,
) -> Self
pub fn new( inner: G, feature_name: impl Into<String>, tier_name: impl Into<String>, validator: Arc<LicenseValidator>, ) -> Self
Creates a new license-checked guard wrapper.
Sourcepub fn feature_name(&self) -> &str
pub fn feature_name(&self) -> &str
Returns the feature name.
Sourcepub async fn validate_license(&self) -> LicensedGuardResult<()>
pub async fn validate_license(&self) -> LicensedGuardResult<()>
Validates the license for this guard.